<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>ExLayerCustomProperty</name>
    <message>
        <location filename="../ExLayerCustomProperty.js" line="+43"/>
        <source>Added custom property &apos;MyCustomProperty&apos; to layer &apos;0&apos;.</source>
        <translation>Benutzerdefinierte Eigenschaft &quot;MyCustomProperty&quot; zu Layer &apos;0&apos; hinzugefügt.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Add Custom Property to a Layer</source>
        <translation>Benutzerdefinierte Eigenschaft zu Layer hinzufügen</translation>
    </message>
    <message>
        <source>Add custom property to a layer</source>
        <translation type="vanished">Benutzerdefinierte Eigenschaft zu Layer hinzufügen</translation>
    </message>
</context>
</TS>
